==> ansys_dyna_core-0.6.1-py3-none-any.whl: ansys/dyna/core/keywords/keyword_classes/auto/deformable_to_rigid.py <==
# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.keyword_base import KeywordBase

class DeformableToRigid(KeywordBase):
    """DYNA DEFORMABLE_TO_RIGID keyword"""

    keyword = "DEFORMABLE"
    subkeyword = "TO_RIGID"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "pid",
                        int,
                        0,
                        10,
                        kwargs.get("pid")
                    ),
                    Field(
                        "lrb",
                        int,
                        10,
                        10,
                        kwargs.get("lrb", 0)
                    ),
                    Field(
                        "ptype",
                        str,
                        20,
                        10,
                        kwargs.get("ptype", "PART")
                    ),
                ],
            ),
        ]

    @property
    def pid(self) -> typing.Optional[int]:
        """Get or set the Part ID for the part that will switched to a rigid material, also see *PART.
        """ # nopep8
        return self._cards[0].get_value("pid")

    @pid.setter
    def pid(self, value: int) -> None:
        self._cards[0].set_value("pid", value)

    @property
    def lrb(self) -> int:
        """Get or set the Part ID of the lead rigid body to which the part is merged.
        EQ.0: Part becomes either an independent or lead rigid body.
        """ # nopep8
        return self._cards[0].get_value("lrb")

    @lrb.setter
    def lrb(self, value: int) -> None:
        self._cards[0].set_value("lrb", value)

    @property
    def ptype(self) -> str:
        """Get or set the Type of PID:
        EQ."PART": PID is a part ID.
        EQ."PSET": PID is a part set ID.All parts included in part set PID will be switched to rigid at the start of the calculation.
        """ # nopep8
        return self._cards[0].get_value("ptype")

    @ptype.setter
    def ptype(self, value: str) -> None:
        if value not in ["PART", "PSET"]:
            raise Exception("""ptype must be one of {"PART","PSET"}""")
        self._cards[0].set_value("ptype", value)

==> ansys_dyna_core-0.7.0-py3-none-any.whl: ansys/dyna/core/keywords/keyword_classes/auto/deformable_to_rigid.py <==
# Copyright (C) 2021 - 2024 ANSYS, Inc. and/or its affiliates.
# SPDX-License-Identifier: MIT
#
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

import typing
from ansys.dyna.core.lib.card import Card, Field, Flag
from ansys.dyna.core.lib.config import use_lspp_defaults
from ansys.dyna.core.lib.keyword_base import KeywordBase

class DeformableToRigid(KeywordBase):
    """DYNA DEFORMABLE_TO_RIGID keyword"""

    keyword = "DEFORMABLE"
    subkeyword = "TO_RIGID"

    def __init__(self, **kwargs):
        super().__init__(**kwargs)
        self._cards = [
            Card(
                [
                    Field(
                        "pid",
                        int,
                        0,
                        10,
                        kwargs.get("pid")
                    ),
                    Field(
                        "lrb",
                        int,
                        10,
                        10,
                        kwargs.get("lrb", 0 if use_lspp_defaults() else None)
                    ),
                    Field(
                        "ptype",
                        str,
                        20,
                        10,
                        kwargs.get("ptype", "PART" if use_lspp_defaults() else None)
                    ),
                ],
            ),
        ]

    @property
    def pid(self) -> typing.Optional[int]:
        """Get or set the Part ID for the part that will switched to a rigid material, also see *PART.
        """ # nopep8
        return self._cards[0].get_value("pid")

    @pid.setter
    def pid(self, value: int) -> None:
        self._cards[0].set_value("pid", value)

    @property
    def lrb(self) -> int:
        """Get or set the Part ID of the lead rigid body to which the part is merged.
        EQ.0: Part becomes either an independent or lead rigid body.
        """ # nopep8
        return self._cards[0].get_value("lrb")

    @lrb.setter
    def lrb(self, value: int) -> None:
        self._cards[0].set_value("lrb", value)

    @property
    def ptype(self) -> str:
        """Get or set the Type of PID:
        EQ."PART": PID is a part ID.
        EQ."PSET": PID is a part set ID.All parts included in part set PID will be switched to rigid at the start of the calculation.
        """ # nopep8
        return self._cards[0].get_value("ptype")

    @ptype.setter
    def ptype(self, value: str) -> None:
        if value not in ["PART", "PSET"]:
            raise Exception("""ptype must be one of {"PART","PSET"}""")
        self._cards[0].set_value("ptype", value)
